@@ -72,7 +72,7 @@ class Player(discord.VoiceProtocol):
         self.channel: discord.VoiceChannel = channel
         self._node: Optional[Node] = NodePool.balanced()
         self._track: Optional[Track] = None
-        self._volume: int = 100
+        self._volume: float = 1.0
         self._filters: Dict[str, LavapyFilter] = {}
         self._queue: Queue = Queue(self)
         self._voiceState: Dict[str, Any] = {}
@@ -101,7 +101,7 @@ class Player(discord.VoiceProtocol):
         return self._track
 
     @property
-    def volume(self) -> int:
+    def volume(self) -> float:
         """Returns the current volume."""
         return self._volume
 
@@ -183,7 +183,7 @@ class Player(discord.VoiceProtocol):
             self.queue.addIterable(temp)
         return track
 
-    def repeat(self) -> None:
+    def startRepeat(self) -> None:
         """
         Repeats the currently playing track.
 
@@ -205,7 +205,7 @@ class Player(discord.VoiceProtocol):
         RepeatException
             The player is not repeating.
         """
-        if self.isRepeating:
+        if not self.isRepeating:
             raise RepeatException("The player is not repeating..")
         self._repeat = False
 
@@ -291,7 +291,7 @@ class Player(discord.VoiceProtocol):
         self.cleanup()
         logger.info(f"Disconnected from voice channel {self.channel.id}")
 
-    async def play(self, track: Union[Track, PartialResource, MultiTrack], startTime: int = 0, endTime: int = 0, volume: int = 100, replace: bool = True, pause: bool = False) -> Optional[Track]:
+    async def play(self, track: Union[Track, PartialResource, MultiTrack], startTime: int = 0, endTime: int = 0, volume: float = 1, replace: bool = True, pause: bool = False) -> Optional[Track]:
         """|coro|
 
         Plays a given resource. If this resource is a :class:`Track`, it is played normally. However, if it is a
@@ -308,7 +308,7 @@ class Player(discord.VoiceProtocol):
         endTime: int
             The position in milliseconds to end at. By default, this is the end.
         volume: int
-            The volume at which the player should play the track at.
+            The volume at which the player should play the track at. This should be a value between 0 and 5 where 1 is 100%.
         replace: bool
             A bool stating if the current track should be replaced or not.
         pause: bool
@@ -329,6 +329,8 @@ class Player(discord.VoiceProtocol):
             if isinstance(track, list):
                 track = track[0]
             track = self._multitrackCheck(track)
+        if not (0 <= volume <= 5):
+            raise ValueError("Volume must be a value between 0 and 5.")
         newTrack = {
             "op": "play",
             "guildId": str(self.guild.id),
@@ -423,17 +425,19 @@ class Player(discord.VoiceProtocol):
         await self.node._send(seek)
         logger.debug(f"Seeked to position {position} for guild {self.guild.id}")
 
-    async def setVolume(self, volume: int) -> None:
+    async def setVolume(self, volume: float) -> None:
         """|coro|
 
         Changes the :class:`Player`'s volume.
 
         Parameters
         ----------
-        volume: int
-            The new volume.
+        volume: float
+            The new volume. This should be a value between 0 and 5 where 1 is 100%.
         """
-        self._volume = max(min(volume, 1000), 0)
+        if not (0 <= volume <= 5):
+            raise ValueError("Volume must be a value between 0 and 5.")
+        self._volume = volume
         volume = {
             "op": "volume",
             "guildId": str(self.guild.id),
